==================
Timeseries modules
==================

Dipole angle
============

Description
***********

.. automodule:: maicos.modules.timeseries.DipoleAngle
    :members:
    :undoc-members:
    :show-inheritance:

Kinetic energy
==============

Description
***********

.. automodule:: maicos.modules.timeseries.KineticEnergy
    :members:
    :undoc-members:
    :show-inheritance:
